"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.AccountActions = void 0;
/**
 * @packageDocumentation
 * @module AccountUIContext
 */

/**
 * Named dispatch actions for account-related global state changes (i.e. login, forgot password, set password, verify reset code).
 */
const AccountActions = {
  // Login
  loginStarted: (email, transitId) => ({
    type: 'Authentication/Login/Started',
    payload: {
      email,
      transitId
    }
  }),
  loginSucceeded: (email, transitId) => ({
    type: 'Authentication/Login/Succeeded',
    payload: {
      email,
      transitId
    }
  }),
  loginFailed: (email, transitId, errorMessage) => ({
    type: 'Authentication/Login/Failed',
    payload: {
      email,
      transitId,
      errorMessage
    }
  }),
  resetLogin: () => ({
    type: 'Authentication/Login/Reset'
  }),
  // Logout
  logout: () => ({
    type: 'Authentication/Logout/Reset'
  }),
  // Reset password ("forgot password")
  resetPasswordReset: () => ({
    type: 'Authentication/ResetPassword/Reset'
  }),
  resetPasswordStarted: (email, transitId) => ({
    type: 'Authentication/ResetPassword/Started',
    payload: {
      email,
      transitId
    }
  }),
  resetPasswordSucceeded: (email, transitId) => ({
    type: 'Authentication/ResetPassword/Succeeded',
    payload: {
      email,
      transitId
    }
  }),
  resetPasswordFailed: (email, transitId, errorMessage) => ({
    type: 'Authentication/ResetPassword/Failed',
    payload: {
      email,
      transitId,
      errorMessage
    }
  }),
  // Verify code for reset password (code from "forgot password" email)
  verifyResetCodeReset: () => ({
    type: 'Authentication/VerifyResetCode/Reset'
  }),
  verifyResetCodeStarted: transitId => ({
    type: 'Authentication/VerifyResetCode/Started',
    payload: {
      transitId
    }
  }),
  verifyResetCodeSucceeded: transitId => ({
    type: 'Authentication/VerifyResetCode/Succeeded',
    payload: {
      transitId
    }
  }),
  verifyResetCodeFailed: (transitId, errorMessage) => ({
    type: 'Authentication/VerifyResetCode/Failed',
    payload: {
      transitId,
      errorMessage
    }
  }),
  // Set password (after a "forgot password" request and verifying a code)
  setPasswordReset: () => ({
    type: 'Authentication/SetPassword/Reset'
  }),
  setPasswordStarted: transitId => ({
    type: 'Authentication/SetPassword/Started',
    payload: {
      transitId
    }
  }),
  setPasswordSucceeded: transitId => ({
    type: 'Authentication/SetPassword/Succeeded',
    payload: {
      transitId
    }
  }),
  setPasswordFailed: (transitId, errorMessage) => ({
    type: 'Authentication/SetPassword/Failed',
    payload: {
      transitId,
      errorMessage
    }
  })
};
exports.AccountActions = AccountActions;
//# sourceMappingURL=dispatchActions.js.map